summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecontactproperty.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kopete/libkopete/kopetecontactproperty.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopetecontactproperty.h')
-rw-r--r--kopete/libkopete/kopetecontactproperty.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kopete/libkopete/kopetecontactproperty.h b/kopete/libkopete/kopetecontactproperty.h
index b5c8f060..f7213faa 100644
--- a/kopete/libkopete/kopetecontactproperty.h
+++ b/kopete/libkopete/kopetecontactproperty.h
@@ -19,7 +19,7 @@
#ifndef _KOPETECONTACTPROPERTY_H_
#define _KOPETECONTACTPROPERTY_H_
-#include <qvariant.h>
+#include <tqvariant.h>
#include "kopete_export.h"
@@ -56,9 +56,9 @@ class KOPETE_EXPORT ContactPropertyTmpl
* @param privateProp if true, properties based on this template won't be
* visible to the user
**/
- ContactPropertyTmpl( const QString &key,
- const QString &label,
- const QString &icon = QString::null,
+ ContactPropertyTmpl( const TQString &key,
+ const TQString &label,
+ const TQString &icon = TQString::null,
bool persistent = false,
bool richText = false,
bool privateProp = false );
@@ -80,17 +80,17 @@ class KOPETE_EXPORT ContactPropertyTmpl
* Getter for the unique key. Properties based on this template will be
* stored with this key
**/
- const QString &key() const;
+ const TQString &key() const;
/**
* Getter for i18ned label
**/
- const QString &label() const;
+ const TQString &label() const;
/**
* Getter for icon to show aside or instead of @p label()
**/
- const QString &icon() const;
+ const TQString &icon() const;
/**
* Returns true if properties based on this template should
@@ -119,9 +119,9 @@ class KOPETE_EXPORT ContactPropertyTmpl
bool isNull() const;
/**
* A Map of QString and ContactPropertyTmpl objects, based on QMap
**/
- typedef QMap<QString, ContactPropertyTmpl> Map;
+ typedef TQMap<TQString, ContactPropertyTmpl> Map;
private:
ContactPropertyTmplPrivate *d;
@@ -149,7 +149,7 @@ class KOPETE_EXPORT ContactProperty
* @param tmpl The contact property template this property is based on
* @param value The value this Property holds
**/
- ContactProperty(const ContactPropertyTmpl &tmpl, const QVariant &value);
+ ContactProperty(const ContactPropertyTmpl &tmpl, const TQVariant &value);
/** Destructor **/
~ContactProperty();
@@ -162,7 +162,7 @@ class KOPETE_EXPORT ContactProperty
/**
* Getter for this properties value
**/
- const QVariant &value() const;
+ const TQVariant &value() const;
/**
* The null, i.e. empty, ContactProperty
@@ -183,10 +183,10 @@ class KOPETE_EXPORT ContactProperty
/**
* A map of key,ContactProperty items
**/
- typedef QMap<QString, ContactProperty> Map;
+ typedef TQMap<TQString, ContactProperty> Map;
private:
- QVariant mValue;
+ TQVariant mValue;
ContactPropertyTmpl mTemplate;
};
@@ -119,9 +119,9 @@ class KOPETE_EXPORT ContactPropertyTmpl
bool isNull() const;
/**
- * A Map of QString and ContactPropertyTmpl objects, based on QMap
+ * A Map of TQString and ContactPropertyTmpl objects, based on QMap
**/